/**
 * Stores a property parameter without any type check
 * @param path [in] property path
 * @param value [in] property value
 */
function storeSubParameter(path, value) {
    try 
    {
        lInfo.logln('store at |' + path + "| value: |" + value + "|" );
        Property.setProperty('/usr/events/' + path, value);
        Property.setFlag('/usr/events/' + path, 'ARCHIVE', true);
        if (fLocalCopy) {
            Property.setProperty('/scripts/system-addon-user-defined-actions/' + path, value);
            Property.setFlag('/scripts/system-addon-user-defined-actions/' + path, 'ARCHIVE', true);
        }
    }
    catch (e)
    {
        lWarn.logln("Exception beim storeSubParameter " + e + " Path " + path  + " value " + value);
    }        
}

/**
 * Store a integer property parameter.
 * converts provided value whenever possible to an integer. Discard the the value if this is not possible.
 * @param path [in] property path
 * @param value [in] value to store should be integer
 * @returns {Boolean} returns false if value could not be converted to integer
 */
function checkAndStoreIntParameter(path, value) {
    try 
    {
        lInfo.logln('store integer at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var intValue = parseInt("" + value);
        if (!isNaN(intValue)) {
            Property.setProperty('/usr/events/' + path, intValue);
            Property.setFlag('/usr/events/' + path, 'ARCHIVE', true);
            if (fLocalCopy) {
                Property.setProperty('/scripts/system-addon-user-defined-actions/' + path, intValue);
                Property.setFlag('/scripts/system-addon-user-defined-actions/' + path, 'ARCHIVE', true);
            }
            sucessCode = true;
        } else {
            lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreIntParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a string property parameter.
 * check weather the provided value is a string. In case it's a number it is converted to string, 
 * in any other cases it is discarded
 * @param path [in] property path
 * @param value [in] value to store should be string or at least a number
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreStringParameter(path, value) {
    try 
    {
        lInfo.logln('store string at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var stringValue = (typeof(value) === "number") ? String(value) : value;
        if (typeof(stringValue) === "string") {
            Property.setProperty('/usr/events/' + path, stringValue);
            Property.setFlag('/usr/events/' + path, 'ARCHIVE', true);
            if (fLocalCopy) {
                Property.setProperty('/scripts/system-addon-user-defined-actions/' + path, stringValue);
                Property.setFlag('/scripts/system-addon-user-defined-actions/' + path, 'ARCHIVE', true);
            }
            sucessCode = true;
        } else {
            lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreStringParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a boolean property parameter.
 * convert value if possible. In case In case conversion is not possible 
 * the value is discarded.
 * @param path [in] property path
 * @param value [in] value to store should be a boolean
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreBoolParameter(path, value) {
    try 
    {
        lInfo.logln('store boolean at |' + path + "| value: |" + value + "|" );
        var successCode = false;
        var boolValue = false;
        if (typeof(value) === "boolean") {
            Property.setProperty('/usr/events/' + path, value);
            Property.setFlag('/usr/events/' + path, 'ARCHIVE', true);       
            if (fLocalCopy) {
                Property.setProperty('/scripts/system-addon-user-defined-actions/' + path, value);
                Property.setFlag('/scripts/system-addon-user-defined-actions/' + path, 'ARCHIVE', true);
            }
            successCode = true;
        } else {
            if (typeof(value) === "string") {
                if (value === "true") {
                    boolValue = true;
                }
                Property.setProperty('/usr/events/' + path, boolValue);
                Property.setFlag('/usr/events/' + path, 'ARCHIVE', true);       
                if (fLocalCopy) {
                    Property.setProperty('/scripts/system-addon-user-defined-actions/' + path, boolValue);
                    Property.setFlag('/scripts/system-addon-user-defined-actions/' + path, 'ARCHIVE', true);
                }
                successCode = true;
            } else {
                lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
            }
        }
        return successCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreBoolParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}